@@ -2,7 +2,7 @@
   This file is part of the KDE reminder agent.
 
   Copyright (c) 2000,2003 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (c) 2008-2009 Allen Winter <winter@kde.org>
+  Copyright (c) 2008-2020 Allen Winter <winter@kde.org>
   Copyright (c) 2009-2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
   This program is free software; you can redistribute it and/or modify
@@ -24,59 +24,51 @@
   without including the source code for Qt in the source distribution.
 */
 
-#include <config-korganizer.h>
+#include "config-korganizer.h"
 #include "alarmdialog.h"
-#include "korganizer_interface.h"
 #include "mailclient.h"
+#include "korganizer_interface.h"
 #include "koalarmclient_debug.h"
 
 #include "notifications_interface.h" // DBUS-generated
 #include "dbusproperties.h" // DBUS-generated
 
+#include <CalendarSupport/IdentityManager>
 #include <CalendarSupport/IncidenceViewer>
 #include <CalendarSupport/KCalPrefs>
-#include <CalendarSupport/IdentityManager>
 #include <CalendarSupport/Utils>
 
-#include <IncidenceEditor/IncidenceDialog>
-#include <IncidenceEditor/IncidenceDialogFactory>
-
-#include <KCalendarCore/Event>
-#include <KCalendarCore/Todo>
 #include <KCalUtils/IncidenceFormatter>
 
 #include <KIdentityManagement/Identity>
 
-#include <AkonadiCore/Item>
+#include <IncidenceEditor/IncidenceDialog>
+#include <IncidenceEditor/IncidenceDialogFactory>
 
 #include <MailTransport/TransportManager>
-#include <QUrl>
 
-#include <KComboBox>
-#include <QHBoxLayout>
+#include <KConfigGroup>
+#include <KIconLoader>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KNotification>
 #include <KSharedConfig>
 #include <KToolInvocation>
 #include <KWindowSystem>
-#include <KIconLoader>
-#include <QIcon>
-#include <phonon/mediaobject.h>
-#include <QLabel>
+
+#include <QDialogButtonBox>
+#include <QHeaderView>
+#include <QComboBox>
 #include <QKeyEvent>
+#include <QLabel>
+#include <QPushButton>
 #include <QSpinBox>
 #include <QTreeWidget>
 #include <QVBoxLayout>
-#include <KConfigGroup>
-#include <QDialogButtonBox>
-#include <QPushButton>
-#include <QToolButton>
-#include <QHeaderView>
 
-using namespace KIdentityManagement;
+#include <phonon/mediaobject.h>
+
 using namespace KCalendarCore;
-using namespace KCalUtils;
 
 // fallback defaults
 static int defSuspendVal = 5;
@@ -144,9 +136,8 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
     //    Ok => Suspend
 
     if (calendar) {
-        connect(
-            calendar.data(), &Akonadi::ETMCalendar::calendarChanged, this,
-            &AlarmDialog::slotCalendarChanged);
+        connect(calendar.data(), &Akonadi::ETMCalendar::calendarChanged,
+                this, &AlarmDialog::slotCalendarChanged);
         Akonadi::IncidenceChanger *changer = calendar->incidenceChanger();
         changer->setShowDialogsOnError(false);
     }
@@ -167,11 +158,10 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
     }
 
     defSuspendVal = generalConfig.readEntry("DefaultSuspendValue", defSuspendVal);
-    int suspendVal = generalConfig.readEntry("SuspendValue", defSuspendVal);
-
     defSuspendUnit = generalConfig.readEntry("DefaultSuspendUnit", defSuspendUnit);
-    SuspendUnit suspendUnit = static_cast<SuspendUnit>(generalConfig.readEntry("SuspendUnit",
-                                                                               defSuspendUnit));
+
+    int suspendVal = defSuspendVal;
+    int suspendUnit = defSuspendUnit;
 
     QWidget *topBox = new QWidget(this);
     setWindowTitle(i18nc("@title:window", "Reminders"));
@@ -179,7 +169,7 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
     QDialogButtonBox *buttonBox = new QDialogButtonBox(this);
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     mainLayout->addWidget(topBox);
-    mOkButton = new QToolButton;
+    mOkButton = new QPushButton;
     mOkButton->setShortcut(Qt::CTRL | Qt::Key_Return);
     mUser1Button = new QPushButton;
     mUser1Button->setDefault(false);
@@ -307,7 +297,7 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
 
     l->setBuddy(mSuspendSpin);
 
-    mSuspendUnit = new KComboBox(suspendBox);
+    mSuspendUnit = new QComboBox(suspendBox);
     suspendBoxHBoxLayout->addWidget(mSuspendUnit);
     mSuspendUnit->addItem(i18nc("@item:inlistbox suspend in terms of minutes", "minute(s)"));
     mSuspendUnit->addItem(i18nc("@item:inlistbox suspend in terms of hours", "hour(s)"));
@@ -321,28 +311,7 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
               "Each reminder for the selected incidences will be suspended "
               "using this time unit. You can set the number of time units "
               "in the adjacent number entry input."));
-    mSuspendUnit->setCurrentIndex(static_cast<int>(suspendUnit));
-
-    mSuspendMenu = new QMenu();
-    mSuspendMenu->setToolTipsVisible(true);
-    mOkButton->setMenu(mSuspendMenu);
-
-    QAction *mResetSuspendAction = new QAction(i18nc("@action:inmenu", "Reset"));
-    connect(mResetSuspendAction, &QAction::triggered, this, &AlarmDialog::resetSuspend);
-    mResetSuspendAction->setToolTip(i18nc("@info:tooltip",
-                                          "Reset the suspend time to the default value"));
-    mResetSuspendAction->setWhatsThis(i18nc("@info:whatsthis",
-                                            "Reset the suspend time to the default value"));
-    mSuspendMenu->addAction(mResetSuspendAction);
-
-    QAction *mSetDefaultSuspendAction = new QAction(i18nc("@action:inmenu", "Set as Default"));
-    connect(mSetDefaultSuspendAction, &QAction::triggered, this, &AlarmDialog::setDefaultSuspend);
-    mSetDefaultSuspendAction->setToolTip(i18nc("@info:tooltip",
-                                               "Set the current suspend time as the new default"));
-    mSetDefaultSuspendAction->setWhatsThis(i18nc("@info:whatsthis",
-                                                 "Press this button to set the current suspend "
-                                                 "time as the new default value"));
-    mSuspendMenu->addAction(mSetDefaultSuspendAction);
+    mSuspendUnit->setCurrentIndex(suspendUnit);
 
     connect(&mSuspendTimer, &QTimer::timeout, this, &AlarmDialog::wakeUp);
 
@@ -355,10 +324,11 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
 
     QDBusConnection dbusConn = QDBusConnection::sessionBus();
     if (dbusConn.interface()->isServiceRegistered(QString::fromLatin1(s_fdo_notifications_service))) {
-        OrgFreedesktopDBusPropertiesInterface *propsIface = new OrgFreedesktopDBusPropertiesInterface(
-                QString::fromLatin1(s_fdo_notifications_service),
-                QString::fromLatin1(s_fdo_notifications_path),
-                dbusConn, this);
+        OrgFreedesktopDBusPropertiesInterface *propsIface
+            = new OrgFreedesktopDBusPropertiesInterface(
+                  QString::fromLatin1(s_fdo_notifications_service),
+                  QString::fromLatin1(s_fdo_notifications_path),
+                  dbusConn, this);
         connect(propsIface, &OrgFreedesktopDBusPropertiesInterface::PropertiesChanged,
                 this, &AlarmDialog::slotDBusNotificationsPropertiesChanged);
     }
@@ -391,9 +361,7 @@ static QString cleanSummary(const QString &summary)
     return retStr.replace(QLatin1Char('\n'), QLatin1Char(' '));
 }
 
-void AlarmDialog::addIncidence(const Akonadi::Item &incidenceitem,
-                               const QDateTime &reminderAt,
-                               const QString &displayText)
+void AlarmDialog::addIncidence(const Akonadi::Item &incidenceitem, const QDateTime &reminderAt, const QString &displayText)
 {
     Incidence::Ptr incidence = CalendarSupport::incidence(incidenceitem);
     ReminderTreeItem *item = searchByItem(incidenceitem);
@@ -421,8 +389,9 @@ void AlarmDialog::addIncidence(const Akonadi::Item &incidenceitem,
 
     item->setText(2, QLocale().toString(item->mTrigger, QLocale::ShortFormat));
     QString tip
-        = IncidenceFormatter::toolTipStr(
-              CalendarSupport::displayName(mCalendar.data(), incidenceitem.parentCollection()),
+        = KCalUtils::IncidenceFormatter::toolTipStr(
+              CalendarSupport::displayName(mCalendar.data(),
+                                           incidenceitem.parentCollection()),
               incidence, item->mRemindAt.date(), true);
     if (!item->mDisplayText.isEmpty()) {
         tip += QLatin1String("<br>") + item->mDisplayText;
@@ -733,8 +702,7 @@ void AlarmDialog::eventNotification()
 
                 // if the program name contains spaces escape it
                 if (program.contains(QLatin1Char(' '))
-                    && !(program.startsWith(QLatin1Char('\"'))
-                         && program.endsWith(QLatin1Char('\"')))) {
+                    && !(program.startsWith(QLatin1Char('\"')) && program.endsWith(QLatin1Char('\"')))) {
                     program = QLatin1Char('\"') + program + QLatin1Char('\"');
                 }
 
@@ -751,7 +719,7 @@ void AlarmDialog::eventNotification()
                 player->play();
             } else if (alarm->type() == Alarm::Email) {
                 QString from = CalendarSupport::KCalPrefs::instance()->email();
-                Identity id = mIdentityManager->identityForAddress(from);
+                KIdentityManagement::Identity id = mIdentityManager->identityForAddress(from);
                 QString to;
                 if (alarm->mailAddresses().isEmpty()) {
                     to = from;
@@ -782,25 +750,25 @@ void AlarmDialog::eventNotification()
                     subject = i18nc("@title", "Reminder: %1", alarm->mailSubject());
                 }
 
-                QString body = IncidenceFormatter::mailBodyStr(parent.staticCast<IncidenceBase>());
+                QString body = KCalUtils::IncidenceFormatter::mailBodyStr(parent.staticCast<IncidenceBase>());
                 if (!alarm->mailText().isEmpty()) {
                     body += QLatin1Char('\n') + alarm->mailText();
                 }
                 //TODO: support attachments
                 KOrg::MailClient mailer;
-                const bool sendStatus =
-                    mailer.send(id, from, to, QString(), subject, body, true, false, QString(),
-                                MailTransport::TransportManager::self()->defaultTransportName());
+                const bool sendStatus
+                    = mailer.send(id, from, to, QString(), subject, body, true, false, QString(),
+                                  MailTransport::TransportManager::self()->defaultTransportName());
                 if (!sendStatus) {
                     KNotification::event(QStringLiteral("mailremindersent"),
-                        QString(),
-                        i18nc("@info email subject, error message",
-                              "<warning>Failed to send the Email reminder for %1. %2</warning>",
-                              subject, mailer.errorMsg()),
-                        QStringLiteral("korgac"),
-                        nullptr,
-                        KNotification::CloseOnTimeout,
-                        QStringLiteral("korgac"));
+                                         QString(),
+                                         i18nc("@info email subject, error message",
+                                               "<warning>Failed to send the Email reminder for %1. %2</warning>",
+                                               subject, mailer.errorMsg()),
+                                         QStringLiteral("korgac"),
+                                         nullptr,
+                                         KNotification::CloseOnTimeout,
+                                         QStringLiteral("korgac"));
                 }
             }
         }
@@ -818,9 +786,9 @@ void AlarmDialog::wakeUp()
     QDBusConnection dbusConn = QDBusConnection::sessionBus();
     if (dbusConn.interface()->isServiceRegistered(QString::fromLatin1(s_fdo_notifications_service))) {
         OrgFreedesktopNotificationsInterface iface(
-                QString::fromLatin1(s_fdo_notifications_service),
-                QString::fromLatin1(s_fdo_notifications_path),
-                dbusConn);
+            QString::fromLatin1(s_fdo_notifications_service),
+            QString::fromLatin1(s_fdo_notifications_path),
+            dbusConn);
         if (iface.inhibited()) {
             return;
         }
@@ -857,9 +825,7 @@ void AlarmDialog::wakeUp()
     Q_EMIT reminderCount(activeCount());
 }
 
-void AlarmDialog::slotDBusNotificationsPropertiesChanged(const QString &interface,
-                                                         const QVariantMap &changedProperties,
-                                                         const QStringList &invalidatedProperties)
+void AlarmDialog::slotDBusNotificationsPropertiesChanged(const QString &interface, const QVariantMap &changedProperties, const QStringList &invalidatedProperties)
 {
     Q_UNUSED(interface); // always "org.freedesktop.Notifications"
     Q_UNUSED(invalidatedProperties);
@@ -898,8 +864,6 @@ void AlarmDialog::slotSave()
     generalConfig.writeEntry("Size", mRect.size());
     generalConfig.writeEntry("DefaultSuspendValue", defSuspendVal);
     generalConfig.writeEntry("DefaultSuspendUnit", defSuspendUnit);
-    generalConfig.writeEntry("SuspendValue", mSuspendSpin->value());
-    generalConfig.writeEntry("SuspendUnit", mSuspendUnit->currentIndex());
 
     config->sync();
 }
@@ -963,8 +927,8 @@ void AlarmDialog::updateButtons()
         mUser1Button->setEnabled(false);
     }
     if (enabled) {
-       mIncidenceTree->setFocus();
-       mIncidenceTree->setCurrentItem(selection.first());
+        mIncidenceTree->setFocus();
+        mIncidenceTree->setCurrentItem(selection.first());
     }
 }
 
@@ -1033,9 +997,7 @@ void AlarmDialog::accept()
 }
 
 /** static */
-QDateTime AlarmDialog::triggerDateForIncidence(const Incidence::Ptr &incidence,
-                                               const QDateTime &reminderAt,
-                                               QString &displayStr)
+QDateTime AlarmDialog::triggerDateForIncidence(const Incidence::Ptr &incidence, const QDateTime &reminderAt, QString &displayStr)
 {
     QDateTime result;
 
@@ -1160,10 +1122,10 @@ bool AlarmDialog::openIncidenceEditorThroughKOrganizer(const Incidence::Ptr &inc
 bool AlarmDialog::openIncidenceEditorNG(const Akonadi::Item &item)
 {
     Incidence::Ptr incidence = CalendarSupport::incidence(item);
-    IncidenceEditorNG::IncidenceDialog *dialog =
-        IncidenceEditorNG::IncidenceDialogFactory::create(
-            false, /*doesn't need initial saving*/
-            incidence->type(), nullptr, this);
+    IncidenceEditorNG::IncidenceDialog *dialog
+        = IncidenceEditorNG::IncidenceDialogFactory::create(
+              false, /*doesn't need initial saving*/
+              incidence->type(), nullptr, this);
     if (!dialog) {
         return false;
     } else {
