@@ -26,33 +26,29 @@
 
 #include <Akonadi/Calendar/ETMCalendar>
 
-#include <KCalendarCore/Incidence>
-
 #include <QDialog>
-#include <QMenu>
 #include <QTimer>
 
-namespace Akonadi {
-class Item;
-}
+class ReminderTreeItem;
 
 namespace KIdentityManagement {
 class IdentityManager;
 }
 
+namespace Akonadi {
+class Item;
+}
+
 namespace CalendarSupport {
 class IncidenceViewer;
 }
 
-class ReminderTreeItem;
+class QComboBox;
 
-class KComboBox;
-
-class QDateTime;
+class QSpinBox;
 class QTreeWidget;
 class QTreeWidgetItem;
-class QSpinBox;
-class QToolButton;
+
 class AlarmDialog : public QDialog
 {
     Q_OBJECT
@@ -110,10 +106,7 @@ protected:
     void showEvent(QShowEvent *event) override;
 
 private Q_SLOTS:
-    void slotDBusNotificationsPropertiesChanged(
-            const QString& interface,
-            const QVariantMap& changedProperties,
-            const QStringList& invalidatedProperties);
+    void slotDBusNotificationsPropertiesChanged(const QString &interface, const QVariantMap &changedProperties, const QStringList &invalidatedProperties);
 
 private:
     void update();
@@ -148,16 +141,13 @@ private:
 
     QRect mRect;
     QSpinBox *mSuspendSpin = nullptr;
-    KComboBox *mSuspendUnit = nullptr;
-    QMenu *mSuspendMenu = nullptr;
-    QAction *mResetSuspendAction = nullptr;
-    QAction *mSetDefaultSuspendAction = nullptr;
+    QComboBox *mSuspendUnit = nullptr;
     QTimer mSuspendTimer;
     QTreeWidgetItem *mLastItem = nullptr;
     QPushButton *mUser1Button = nullptr;
     QPushButton *mUser2Button = nullptr;
     QPushButton *mUser3Button = nullptr;
-    QToolButton *mOkButton = nullptr;
+    QPushButton *mOkButton = nullptr;
 };
 
 #endif
