@@ -52,7 +52,7 @@
 #include <Akonadi/Calendar/StandardCalendarActionManager>
 #include <AkonadiCore/CollectionIdentificationAttribute>
 #include <PimCommonAkonadi/ManageServerSideSubscriptionJob>
-#include "PimCommonAkonadi/MailUtil"
+#include <PimCommonAkonadi/MailUtil>
 
 #include <KActionCollection>
 #include <KCheckableProxyModel>
@@ -309,7 +309,7 @@ public:
             const Akonadi::Collection::Id colId = collection.id();
 
             if (colId == CalendarSupport::KCalPrefs::instance()->defaultCalendarId()) {
-                return i18nc("this is the default calendar", "%1 (Default)", collection.displayName());
+                return i18nc("@item this is the default calendar", "%1 (Default)", collection.displayName());
             }
         }
 
@@ -339,10 +339,12 @@ protected:
     {
         const QModelIndex sourceIndex = sourceModel()->index(row, 0, sourceParent);
         Q_ASSERT(sourceIndex.isValid());
+
         const Akonadi::Collection &col
             = sourceIndex.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
         const Akonadi::CollectionIdentificationAttribute *attr
             = col.attribute<Akonadi::CollectionIdentificationAttribute>();
+
         //We filter the user folders because we insert person nodes for user folders.
         if ((attr && attr->collectionNamespace().startsWith("usertoplevel"))
             || col.name().contains(QLatin1String("Other Users"))) {
@@ -414,7 +416,6 @@ AkonadiCollectionView::AkonadiCollectionView(CalendarView *view, bool hasContext
     , mBaseModel(nullptr)
     , mSelectionProxyModel(nullptr)
     , mAssignColor(nullptr)
-    , mDisableColor(nullptr)
     , mDefaultCalendar(nullptr)
     , mServerSideSubscription(nullptr)
     , mNotSendAddRemoveSignal(false)
@@ -427,7 +428,9 @@ AkonadiCollectionView::AkonadiCollectionView(CalendarView *view, bool hasContext
     topLayout->setContentsMargins(0, 0, 0, 0);
 
     QLineEdit *searchCol = new QLineEdit(this);
-    searchCol->setToolTip(i18nc("info:tooltip", "Set search keyword"));
+    searchCol->setToolTip(i18nc("@info:tooltip", "Set search keyword"));
+    searchCol->setWhatsThis(
+        i18nc("@info:whatsthis", "Lets you search for a keyword in your calendars"));
     searchCol->setClearButtonEnabled(true);
     searchCol->setPlaceholderText(i18nc("@info/plain Displayed grayed-out inside the "
                                         "textbox, verb to search", "Search..."));
@@ -531,8 +534,7 @@ AkonadiCollectionView::AkonadiCollectionView(CalendarView *view, bool hasContext
                         << Akonadi::StandardCalendarActionManager::CreateJournal
                         << Akonadi::StandardCalendarActionManager::EditIncidence;
 
-        for (Akonadi::StandardCalendarActionManager::Type calendarAction :
-             qAsConst(calendarActions)) {
+        for (Akonadi::StandardCalendarActionManager::Type calendarAction : qAsConst(calendarActions)) {
             mActionManager->createAction(calendarAction);
         }
 
@@ -563,35 +565,26 @@ AkonadiCollectionView::AkonadiCollectionView(CalendarView *view, bool hasContext
 
         mActionManager->interceptAction(Akonadi::StandardActionManager::CollectionProperties);
         connect(mActionManager->action(
-                    Akonadi::StandardActionManager::CollectionProperties), &QAction::triggered, mManagerShowCollectionProperties,
-                &ManageShowCollectionProperties::showCollectionProperties);
-
-        mDisableColor = new QAction(mCollectionView);
-        mDisableColor->setText(i18n("&Disable Color"));
-        mDisableColor->setEnabled(false);
-        xmlclient->actionCollection()->addAction(QStringLiteral("disable_color"),
-                                                 mDisableColor);
-        connect(mDisableColor, &QAction::triggered, this, &AkonadiCollectionView::disableColor);
+                    Akonadi::StandardActionManager::CollectionProperties), &QAction::triggered,
+                mManagerShowCollectionProperties, &ManageShowCollectionProperties::showCollectionProperties);
 
         mAssignColor = new QAction(mCollectionView);
-        mAssignColor->setText(i18n("&Assign Color..."));
+        mAssignColor->setText(i18nc("@action:inmenu", "&Set Folder Color..."));
         mAssignColor->setEnabled(false);
         xmlclient->actionCollection()->addAction(QStringLiteral("assign_color"), mAssignColor);
         connect(mAssignColor, &QAction::triggered, this, &AkonadiCollectionView::assignColor);
 
         mDefaultCalendar = new QAction(mCollectionView);
-        mDefaultCalendar->setText(i18n("Set as &Default Calendar"));
+        mDefaultCalendar->setText(i18nc("@action:inmenu", "Set as &Default Folder"));
         mDefaultCalendar->setEnabled(false);
         xmlclient->actionCollection()->addAction(QStringLiteral("set_standard_calendar"),
                                                  mDefaultCalendar);
         connect(mDefaultCalendar, &QAction::triggered, this,
                 &AkonadiCollectionView::setDefaultCalendar);
 
-        mServerSideSubscription = new QAction(QIcon::fromTheme(QStringLiteral(
-                                                                   "folder-bookmarks")),
-                                              i18n("Serverside Subscription..."), this);
-        xmlclient->actionCollection()->addAction(QStringLiteral(
-                                                     "serverside_subscription"),
+        mServerSideSubscription = new QAction(QIcon::fromTheme(QStringLiteral("folder-bookmarks")),
+                                              i18nc("@action:inmenu", "Serverside Subscription..."), this);
+        xmlclient->actionCollection()->addAction(QStringLiteral("serverside_subscription"),
                                                  mServerSideSubscription);
         connect(mServerSideSubscription, &QAction::triggered, this,
                 &AkonadiCollectionView::slotServerSideSubscription);
@@ -600,7 +593,8 @@ AkonadiCollectionView::AkonadiCollectionView(CalendarView *view, bool hasContext
 
 AkonadiCollectionView::~AkonadiCollectionView()
 {
-    //Necessary because it's apparently impossible to detect in the note expander when to save the state before view get's deleted
+    // Need this because it seems impossible to detect in the NodeExpander when to save the state
+    // before the view is deleted.
     mNewNodeExpander->saveState();
 }
 
@@ -644,14 +638,14 @@ void AkonadiCollectionView::setDefaultCalendar()
 
     // Ask if they really want to do this
     const Akonadi::Collection curCol(CalendarSupport::KCalPrefs::instance()->defaultCalendarId());
-    if (curCol.isValid() &&
-        KMessageBox::warningContinueCancel(
+    if (curCol.isValid()
+        && KMessageBox::warningContinueCancel(
             this,
             i18nc("@info",
                   "Do you really want replace your current default calendar with \"%1\"?",
-                   collection.displayName()),
+                  collection.displayName()),
             i18nc("@title:window", "Replace Default Calendar?")) != KMessageBox::Continue) {
-              return;
+        return;
     }
 
     CalendarSupport::KCalPrefs::instance()->setDefaultCalendarId(collection.id());
@@ -680,18 +674,6 @@ void AkonadiCollectionView::assignColor()
     }
 }
 
-void AkonadiCollectionView::disableColor()
-{
-    QModelIndex index = mCollectionView->selectionModel()->currentIndex(); //selectedRows()
-    Q_ASSERT(index.isValid());
-    const Akonadi::Collection collection = CalendarSupport::collectionFromIndex(index);
-    Q_ASSERT(collection.isValid());
-    KOHelper::setResourceColor(collection, QColor());
-    updateMenu();
-    updateView();
-    Q_EMIT colorsChanged();
-}
-
 void AkonadiCollectionView::setCollectionSelectionProxyModel(KCheckableProxyModel *m)
 {
     if (mSelectionProxyModel == m) {
@@ -720,8 +702,7 @@ Akonadi::EntityTreeView *AkonadiCollectionView::view() const
 void AkonadiCollectionView::updateView()
 {
     Q_EMIT resourcesChanged(mSelectionProxyModel
-                            ? mSelectionProxyModel->selectionModel()->hasSelection()
-                            : false);
+                            ? mSelectionProxyModel->selectionModel()->hasSelection() : false);
 }
 
 void AkonadiCollectionView::updateMenu()
@@ -730,8 +711,7 @@ void AkonadiCollectionView::updateMenu()
         return;
     }
     bool enableAction = mCollectionView->selectionModel()->hasSelection();
-    enableAction = enableAction
-                   && (KOPrefs::instance()->agendaViewColors() != KOPrefs::CategoryOnly);
+    enableAction = enableAction && (KOPrefs::instance()->agendaViewColors() != KOPrefs::CategoryOnly);
     mAssignColor->setEnabled(enableAction);
     QModelIndex index = mCollectionView->selectionModel()->currentIndex(); //selectedRows()
 
@@ -742,19 +722,15 @@ void AkonadiCollectionView::updateMenu()
         const Akonadi::Collection collection = CalendarSupport::collectionFromIndex(index);
 
         if (collection.isValid() && !collection.contentMimeTypes().isEmpty()) {
-            const QColor defaultColor = KOHelper::resourceColor(collection);
-            enableAction = enableAction && defaultColor.isValid();
             if (collection.remoteId() == QLatin1String("akonadi_birthdays_resource")) {
-                enableAction = false;
-                mAssignColor->setEnabled(enableAction);
+                mAssignColor->setEnabled(false);
             }
 
-            mDisableColor->setEnabled(enableAction);
             mDefaultCalendar->setEnabled(
-                !KOHelper::isStandardCalendar(collection.id()) &&
-                (collection.rights() & Akonadi::Collection::CanCreateItem) &&
-                !collection.isVirtual() &&
-                collection.contentMimeTypes().contains(KCalendarCore::Event::eventMimeType()));
+                !KOHelper::isStandardCalendar(collection.id())
+                && (collection.rights() & Akonadi::Collection::CanCreateItem)
+                && !collection.isVirtual()
+                && collection.contentMimeTypes().contains(KCalendarCore::Event::eventMimeType()));
             disableStuff = false;
         }
         bool isOnline;
@@ -764,7 +740,6 @@ void AkonadiCollectionView::updateMenu()
         mServerSideSubscription->setEnabled(false);
     }
     if (disableStuff) {
-        mDisableColor->setEnabled(false);
         mDefaultCalendar->setEnabled(false);
         mAssignColor->setEnabled(false);
     }
@@ -819,8 +794,8 @@ void AkonadiCollectionView::deleteCalendar()
 
     if (KMessageBox::warningContinueCancel(
             this,
-            i18n("Do you really want to delete calendar %1?", displayname),
-            i18n("Delete Calendar"),
+            i18nc("@info", "Do you really want to delete calendar %1?", displayname),
+            i18nc("@title:window", "Delete Calendar"),
             KStandardGuiItem::del(),
             KStandardGuiItem::cancel(),
             QString(),
