@@ -47,19 +47,19 @@ public:
     ~KOrganizerIfaceImpl();
 
 public Q_SLOTS:
-    bool openURL(const QString &url);
-    bool mergeURL(const QString &url);
-    bool saveURL();
-    bool saveAsURL(const QString &url);
-    QString getCurrentURLasString() const;
+    Q_REQUIRED_RESULT bool openURL(const QString &url);
+    Q_REQUIRED_RESULT bool mergeURL(const QString &url);
+    Q_REQUIRED_RESULT bool saveURL();
+    Q_REQUIRED_RESULT bool saveAsURL(const QString &url);
+    Q_REQUIRED_RESULT QString getCurrentURLasString() const;
 
-    bool editIncidence(const QString &akonadiUrl);
+    Q_REQUIRED_RESULT bool editIncidence(const QString &akonadiUrl);
     /** @reimp from KOrganizerIface::deleteIncidence()
         @param akonadiUrl the akonadi Item URL of the item to delete. if no such item exists,
         nothing happens
         @return true if the item could be deleted, false otherwise
     */
-    bool deleteIncidence(const QString &akonadiUrl)
+    Q_REQUIRED_RESULT bool deleteIncidence(const QString &akonadiUrl)
     {
         return deleteIncidence(akonadiUrl, false);
     }
@@ -70,7 +70,7 @@ public Q_SLOTS:
       @param force If true, all recurrences and sub-todos (if applicable) will
       be deleted without prompting for confirmation.
     */
-    bool deleteIncidence(const QString &akonadiUrl, bool force);
+    Q_REQUIRED_RESULT bool deleteIncidence(const QString &akonadiUrl, bool force);
 
     /**
       Add an incidence to the active calendar.
@@ -80,28 +80,28 @@ public Q_SLOTS:
                   optionally a VTIMEZONE component. If there is more than one
                   incidence, only the first is added to KOrganizer's calendar.
     */
-    bool addIncidence(const QString &iCal);
+    Q_REQUIRED_RESULT bool addIncidence(const QString &iCal);
 
     /**
       Show a HTML representation of the incidence (the "View.." dialog).
       If no incidence with the given Akonadi Item URL exists, nothing happens.
       @param akonadiUrl The Akonadi Item URL of the incidence to be shown.
     */
-    bool showIncidence(const QString &akonadiUrl);
+    Q_REQUIRED_RESULT bool showIncidence(const QString &akonadiUrl);
 
     /**
       Show an incidence in context. This means showing the todo, agenda or
       journal view (as appropriate) and scrolling it to show the incidence.
       @param akonadiUrl the Akonadi Item URL of the incidence to show.
     */
-    bool showIncidenceContext(const QString &akonadiUrl);
+    Q_REQUIRED_RESULT bool showIncidenceContext(const QString &akonadiUrl);
 
     /**
      * Called by KOrganizerUniqueAppHandler in the kontact plugin
      * Returns true if the command line was successfully handled
      * false otherwise.
      */
-    bool handleCommandLine(const QStringList &args);
+    Q_REQUIRED_RESULT bool handleCommandLine(const QStringList &args);
 
 private:
     ActionManager *mActionManager = nullptr;
