@@ -84,7 +84,7 @@ public:
       probably only select a single event at a time, but some may be able
       to select more than one.
     */
-    virtual KCalCore::DateList selectedIncidenceDates() = 0;
+    virtual KCalendarCore::DateList selectedIncidenceDates() = 0;
 
     /**
        Returns the start of the selection, or an invalid QDateTime if there is no selection
