@@ -44,9 +44,9 @@ public:
 
     static KOCore *self();
 
-    KService::List availablePlugins();
-    KService::List availableCalendarDecorations();
-    KService::List availableParts();
+    Q_REQUIRED_RESULT KService::List availablePlugins();
+    Q_REQUIRED_RESULT KService::List availableCalendarDecorations();
+    Q_REQUIRED_RESULT KService::List availableParts();
 
     CalendarSupport::Plugin *loadPlugin(const KService::Ptr &service);
     CalendarSupport::Plugin *loadPlugin(const QString &);
@@ -58,8 +58,8 @@ public:
     KOrg::Part *loadPart(const KService::Ptr &, KOrg::MainWindow *parent);
     KOrg::Part *loadPart(const QString &, KOrg::MainWindow *parent);
 
-    EventViews::CalendarDecoration::Decoration::List loadCalendarDecorations();
-    KOrg::Part::List loadParts(KOrg::MainWindow *parent);
+    Q_REQUIRED_RESULT EventViews::CalendarDecoration::Decoration::List loadCalendarDecorations();
+    Q_REQUIRED_RESULT KOrg::Part::List loadParts(KOrg::MainWindow *parent);
 
     void addXMLGUIClient(QWidget *, KXMLGUIClient *guiclient);
     void removeXMLGUIClient(QWidget *);
