@@ -215,12 +215,13 @@ void KODialogManager::createCategoryEditor()
 {
     if (!mCategoryEditDialog) {
         mCategoryEditDialog = new Akonadi::TagManagementDialog(mMainView);
-        mCategoryEditDialog->buttons()->setStandardButtons(
-            QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help);
-        connect(mCategoryEditDialog->buttons()->button(
-                    QDialogButtonBox::Help), &QPushButton::clicked, this,
-                &KODialogManager::slotHelp);
-
+        QDialogButtonBox *buttons = mCategoryEditDialog->buttons();
+        if (buttons) {
+            buttons->setStandardButtons(
+                QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help);
+            connect(buttons->button(QDialogButtonBox::Help), &QPushButton::clicked,
+                    this, &KODialogManager::slotHelp);
+        }
         mCategoryEditDialog->setModal(true);
     }
 }
