@@ -24,29 +24,21 @@
 */
 
 #include "koeventpopupmenu.h"
-#include "actionmanager.h"
-#include "kocorehelper.h"
-#include "koglobals.h"
-#include "dialog/noteeditdialog.h"
-
-#include <CalendarSupport/KCalPrefs>
-#include <CalendarSupport/Utils>
-#include <CalendarSupport/CalPrinter>
-#include <CalendarSupport/CalPrintDefaultPlugins>
-
-#include <KCalendarCore/CalFormat>
-#include <KCalendarCore/Incidence>
-#include <Akonadi/Notes/NoteUtils>
-#include <AkonadiCore/CollectionFetchJob>
-#include <AkonadiCore/CollectionFetchScope>
-#include <AkonadiCore/ItemCreateJob>
-
-#include <KActionCollection>
-#include <KMime/Message>
 #include "korganizer_debug.h"
 
-#include <IncidenceEditor/IncidenceDialogFactory>
+#include <AkonadiCore/ItemCreateJob>
+#include <Akonadi/Notes/NoteUtils>
+
+#include <CalendarSupport/CalPrinter>
+#include <CalendarSupport/NoteEditDialog>
+#include <CalendarSupport/Utils>
+
+#include <KCalendarCore/CalFormat>
+
 #include <IncidenceEditor/IncidenceDialog>
+#include <IncidenceEditor/IncidenceDialogFactory>
+
+#include <QCoreApplication>
 
 KOEventPopupMenu::KOEventPopupMenu(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *parent)
     : QMenu(parent)
@@ -88,16 +80,16 @@ void KOEventPopupMenu::init(const Akonadi::ETMCalendar::Ptr &calendar, MenuStyle
               this, &KOEventPopupMenu::printPreview);
 
     // Add more menu actions according to Menu style
-    switch(menuStyle) {
-        case MenuStyle::NormalView:
-            appendEditOnlyItems();
-            appendEventOnlyItems();
-            appendTodoOnlyItems();
-            appendReminderOnlyItems();
-            appendRecurrenceOnlyItems();
-            appendShareOnlyItems();
-        default:
-            break;
+    switch (menuStyle) {
+    case MenuStyle::NormalView:
+        appendEditOnlyItems();
+        appendEventOnlyItems();
+        appendTodoOnlyItems();
+        appendReminderOnlyItems();
+        appendRecurrenceOnlyItems();
+        appendShareOnlyItems();
+    default:
+        break;
     }
 }
 
@@ -121,8 +113,8 @@ void KOEventPopupMenu::appendEventOnlyItems()
     mEventOnlyItems.append(addSeparator());
 
     mEventOnlyItems.append(addAction(QIcon::fromTheme(QStringLiteral("task-new")),
-                                    i18nc("@action:inmenu", "Create To-do from Event"),
-                                    this, &KOEventPopupMenu::createTodo));
+                                     i18nc("@action:inmenu", "Create To-do from Event"),
+                                     this, &KOEventPopupMenu::createTodo));
 
     mEventOnlyItems.append(addAction(QIcon::fromTheme(QStringLiteral("view-pim-notes")),
                                      i18nc("@action:inmenu", "Create Note for Event"),
@@ -153,7 +145,6 @@ void KOEventPopupMenu::appendReminderOnlyItems()
     mToggleReminder = addAction(QIcon::fromTheme(QStringLiteral("appointment-reminder")),
                                 i18nc("@action:inmenu", "&Toggle Reminder"),
                                 this, &KOEventPopupMenu::toggleAlarm);
-
     mReminderOnlyItems.append(mToggleReminder);
 }
 
@@ -169,7 +160,7 @@ void KOEventPopupMenu::appendShareOnlyItems()
 {
     mShareOnlyItems.append(addSeparator());
     mShareOnlyItems.append(addAction(QIcon::fromTheme(QStringLiteral("mail-forward")),
-                                     i18nc("@action:inmenu", "Email as iCalendar..."),
+                                     i18nc("@action:inmenu", "Send as iCalendar..."),
                                      this, &KOEventPopupMenu::forward));
 }
 
@@ -220,9 +211,9 @@ void KOEventPopupMenu::showIncidencePopup(const Akonadi::Item &item, const QDate
         (*it)->setEnabled(true);
     }
     if (mToggleReminder) {
-      mToggleReminder->setText(incidence->hasEnabledAlarms() ?
-                               i18nc("@action:inmenu", "&Toggle Reminder Off") :
-                               i18nc("@action:inmenu", "&Toggle Reminder On"));
+        mToggleReminder->setText(incidence->hasEnabledAlarms()
+                                 ? i18nc("@action:inmenu", "&Toggle Reminder Off")
+                                 : i18nc("@action:inmenu", "&Toggle Reminder On"));
     }
 
     // Enable/Disable menu items valid for reminder Incidences only
@@ -254,6 +245,7 @@ void KOEventPopupMenu::showIncidencePopup(const Akonadi::Item &item, const QDate
         (*it)->setEnabled(true);
     }
 
+    // Show the menu now
     popup(QCursor::pos());
 }
 
@@ -278,12 +270,10 @@ void KOEventPopupMenu::slotPrint()
 
 void KOEventPopupMenu::print(bool preview)
 {
-    KOCoreHelper helper;
     CalendarSupport::CalPrinter printer(this, mCalendar, true);
     connect(this, &KOEventPopupMenu::configChanged, &printer,
             &CalendarSupport::CalPrinter::updateConfig);
 
-    //Item::List selectedIncidences;
     KCalendarCore::Incidence::List selectedIncidences;
     Q_ASSERT(mCurrentIncidence.hasPayload<KCalendarCore::Incidence::Ptr>());
     selectedIncidences.append(mCurrentIncidence.payload<KCalendarCore::Incidence::Ptr>());
@@ -339,17 +329,13 @@ void KOEventPopupMenu::dissociateOccurrences()
 
 void KOEventPopupMenu::forward()
 {
-    KOrg::MainWindow *w = ActionManager::findInstance(QUrl());
-    if (!w || !CalendarSupport::hasIncidence(mCurrentIncidence)) {
-        return;
-    }
-
-    KActionCollection *ac = w->getActionCollection();
-    QAction *action = ac->action(QStringLiteral("schedule_forward"));
-    if (action) {
-        action->trigger();
-    } else {
-        qCCritical(KORGANIZER_LOG) << "What happened to the schedule_forward action?";
+    if (CalendarSupport::hasIncidence(mCurrentIncidence)) {
+        KCalendarCore::Incidence::Ptr incidence = CalendarSupport::incidence(mCurrentIncidence);
+        if (incidence) {
+            Akonadi::ITIPHandler handler(this);
+            handler.setCalendar(mCalendar);
+            handler.sendAsICalendar(incidence, this);
+        }
     }
 }
 
@@ -381,9 +367,9 @@ void KOEventPopupMenu::createEvent()
         newEventItem.setMimeType(KCalendarCore::Event::eventMimeType());
         newEventItem.setPayload<KCalendarCore::Event::Ptr>(event);
 
-        IncidenceEditorNG::IncidenceDialog *dlg =
-            IncidenceEditorNG::IncidenceDialogFactory::create(
-                true, KCalendarCore::IncidenceBase::TypeEvent, nullptr, this);
+        IncidenceEditorNG::IncidenceDialog *dlg
+            = IncidenceEditorNG::IncidenceDialogFactory::create(
+                  true, KCalendarCore::IncidenceBase::TypeEvent, nullptr, this);
         dlg->setObjectName(QStringLiteral("incidencedialog"));
         dlg->load(newEventItem);
         dlg->open();
@@ -414,8 +400,9 @@ void KOEventPopupMenu::createNote()
         newNoteItem.setMimeType(Akonadi::NoteUtils::noteMimeType());
         newNoteItem.setPayload(note.message());
 
-        NoteEditDialog *noteedit = new NoteEditDialog(this);
-        connect(noteedit, &NoteEditDialog::createNote, this, &KOEventPopupMenu::slotCreateNote);
+        CalendarSupport::NoteEditDialog *noteedit = new CalendarSupport::NoteEditDialog(this);
+        connect(noteedit, &CalendarSupport::NoteEditDialog::createNote,
+                this, &KOEventPopupMenu::slotCreateNote);
         noteedit->load(newNoteItem);
         noteedit->show();
     }
@@ -458,9 +445,9 @@ void KOEventPopupMenu::createTodo()
         newTodoItem.setMimeType(KCalendarCore::Todo::todoMimeType());
         newTodoItem.setPayload<KCalendarCore::Todo::Ptr>(todo);
 
-        IncidenceEditorNG::IncidenceDialog *dlg =
-            IncidenceEditorNG::IncidenceDialogFactory::create(
-                true, KCalendarCore::IncidenceBase::TypeTodo, nullptr, this);
+        IncidenceEditorNG::IncidenceDialog *dlg
+            = IncidenceEditorNG::IncidenceDialogFactory::create(
+                  true, KCalendarCore::IncidenceBase::TypeTodo, nullptr, this);
         dlg->setObjectName(QStringLiteral("incidencedialog"));
         dlg->load(newTodoItem);
         dlg->open();
