@@ -34,7 +34,7 @@
 #include <QAction>
 #include <QIcon>
 
-EXPORT_KONTACT_PLUGIN(JournalPlugin, journal)
+EXPORT_KONTACT_PLUGIN_WITH_JSON(JournalPlugin, "journalplugin.json")
 
 JournalPlugin::JournalPlugin(KontactInterface::Core *core, const QVariantList &)
     : KontactInterface::Plugin(core, core, "korganizer", "journal")
@@ -66,9 +66,9 @@ JournalPlugin::~JournalPlugin()
 {
 }
 
-KParts::ReadOnlyPart *JournalPlugin::createPart()
+KParts::Part *JournalPlugin::createPart()
 {
-    KParts::ReadOnlyPart *part = loadPart();
+    KParts::Part *part = loadPart();
 
     if (!part) {
         return nullptr;
