@@ -27,8 +27,6 @@
 #include "calendarinterface.h"
 #include "korg_uniqueapp.h"
 
-#include <Libkdepim/MaillistDrag>
-
 #include <KContacts/VCardDrag>
 
 #include <KCalendarCore/Incidence>
@@ -49,7 +47,7 @@
 #include <QDropEvent>
 #include <QStandardPaths>
 
-EXPORT_KONTACT_PLUGIN(KOrganizerPlugin, korganizer)
+EXPORT_KONTACT_PLUGIN_WITH_JSON(KOrganizerPlugin, "korganizerplugin.json")
 
 KOrganizerPlugin::KOrganizerPlugin(KontactInterface::Core *core, const QVariantList &)
     : KontactInterface::Plugin(core, core, "korganizer", "calendar")
@@ -85,9 +83,9 @@ KontactInterface::Summary *KOrganizerPlugin::createSummaryWidget(QWidget *parent
     return new ApptSummaryWidget(this, parent);
 }
 
-KParts::ReadOnlyPart *KOrganizerPlugin::createPart()
+KParts::Part *KOrganizerPlugin::createPart()
 {
-    KParts::ReadOnlyPart *part = loadPart();
+    KParts::Part *part = loadPart();
 
     if (!part) {
         return nullptr;
@@ -139,7 +137,6 @@ bool KOrganizerPlugin::isRunningStandalone() const
 bool KOrganizerPlugin::canDecodeMimeData(const QMimeData *mimeData) const
 {
     return mimeData->hasText()
-           || KPIM::MailList::canDecode(mimeData)
            || KContacts::VCardDrag::canDecode(mimeData);
 }
 
@@ -198,30 +195,6 @@ void KOrganizerPlugin::processDropEvent(QDropEvent *event)
         return;
     }
 
-    if (KPIM::MailList::canDecode(md)) {
-        KPIM::MailList mails = KPIM::MailList::fromMimeData(md);
-        event->accept();
-        if (mails.count() != 1) {
-            KMessageBox::sorry(
-                core(),
-                i18nc("@info", "Dropping multiple mails is not supported."));
-        } else {
-            KPIM::MailSummary mail = mails.first();
-            QString txt = i18nc("@item", "From: %1\nTo: %2\nSubject: %3",
-                                mail.from(), mail.to(), mail.subject());
-
-            QTemporaryFile tf;
-            tf.setAutoRemove(true);
-            tf.open();
-            QString uri = QLatin1String("kmail:") + QString::number(mail.serialNumber());
-            tf.write(event->mimeData()->data(QStringLiteral("message/rfc822")));
-            interface()->openEventEditor(
-                i18nc("@item", "Mail: %1", mail.subject()), txt,
-                uri, tf.fileName(), QStringList(), QStringLiteral("message/rfc822"));
-            tf.close();
-        }
-        return;
-    }
     qCWarning(KORGANIZERPLUGIN_LOG)
         << QStringLiteral("Cannot handle drop events of type '%1'.").arg(
         event->mimeData()->formats().join(QLatin1Char(';')));
