@@ -26,7 +26,6 @@
 #include "todosummarywidget.h"
 #include "todoplugin.h"
 #include "korganizerinterface.h"
-
 #include <CalendarSupport/Utils>
 #include <CalendarSupport/CalendarSingleton>
 
@@ -281,12 +280,12 @@ void TodoSummaryWidget::updateView()
             urlLabel->setWordWrap(true);
             mLayout->addWidget(urlLabel, counter, 4);
             mLabels.append(urlLabel);
-
-            connect(urlLabel, QOverload<const QString &>::of(
-                        &KUrlLabel::leftClickedUrl), this, &TodoSummaryWidget::viewTodo);
-            connect(urlLabel, QOverload<const QString &>::of(
-                        &KUrlLabel::rightClickedUrl), this, &TodoSummaryWidget::popupMenu);
-
+            connect(urlLabel, &KUrlLabel::leftClickedUrl, this, [this, urlLabel] {
+                viewTodo(urlLabel->url());
+            });
+            connect(urlLabel, &KUrlLabel::rightClickedUrl, this, [this, urlLabel] {
+                popupMenu(urlLabel->url());
+            });
             // State text label
             str = stateStr(todo);
             label = new QLabel(str, this);
