@@ -561,11 +561,12 @@ void SDSummaryWidget::createLabels()
                 urlLabel->setWordWrap(true);
                 mLayout->addWidget(urlLabel, counter, 4);
                 mLabels.append(urlLabel);
-
-                connect(urlLabel, qOverload<const QString &>(&KUrlLabel::leftClickedUrl),
-                        this, &SDSummaryWidget::mailContact);
-                connect(urlLabel, qOverload<const QString &>(&KUrlLabel::rightClickedUrl),
-                        this, &SDSummaryWidget::popupMenu);
+                connect(urlLabel, &KUrlLabel::leftClickedUrl, this, [this, urlLabel] {
+                    mailContact(urlLabel->url());
+                });
+                connect(urlLabel, &KUrlLabel::rightClickedUrl, this, [this, urlLabel] {
+                    popupMenu(urlLabel->url());
+                });
             } else {
                 label = new QLabel(this);
                 label->setText((*addrIt).summary);
