@@ -30,6 +30,9 @@
 #include "korganizer_debug.h"
 #include "korgmigrateapplication.h"
 
+#ifdef WITH_KUSERFEEDBACK
+#include "userfeedback/korganizeruserfeedbackprovider.h"
+#endif
 #include <KLocalizedString>
 #include <KCrash>
 int main(int argc, char **argv)
@@ -52,6 +55,13 @@ int main(int argc, char **argv)
     cmdArgs->process(args);
     aboutData.processCommandLine(cmdArgs);
 
+#ifdef WITH_KUSERFEEDBACK
+    if (cmdArgs->isSet(QStringLiteral("feedback"))) {
+        KOrganizerUserFeedbackProvider *userFeedBackProvider = new KOrganizerUserFeedbackProvider(nullptr);
+        QTextStream(stdout) << userFeedBackProvider->describeDataSources() << '\n';
+        return 0;
+    }
+#endif
     if (!KOrganizerApp::start(args)) {
         qCDebug(KORGANIZER_LOG) << "korganizer already running, exiting";
         return 0;
