@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -23,7 +23,7 @@ KOrganizerPluginInterface::KOrganizerPluginInterface(QObject *parent)
     : PimCommon::PluginInterface(parent)
 {
     setPluginName(QStringLiteral("korganizer"));
-    setServiceTypeName(QStringLiteral("KOrganizer/MainViewPlugin"));
+    setPluginDirectory(QStringLiteral("korganizer/mainview"));
 }
 
 KOrganizerPluginInterface::~KOrganizerPluginInterface()
