@@ -36,9 +36,6 @@
 
 #include <IncidenceEditor/IncidenceEditorSettings>
 
-#include <LibkdepimAkonadi/TagSelectionCombo>
-#include <LibkdepimAkonadi/TagWidgets>
-
 #include <AkonadiCore/AgentFilterProxyModel>
 #include <AkonadiCore/AgentInstanceCreateJob>
 #include <AkonadiCore/AgentManager>
@@ -46,6 +43,7 @@
 #include <AkonadiWidgets/AgentTypeDialog>
 #include <AkonadiWidgets/CollectionComboBox>
 #include <AkonadiWidgets/ManageAccountWidget>
+#include <AkonadiWidgets/TagSelectionComboBox>
 #include <akonadi/calendar/calendarsettings.h>  //krazy:exclude=camelcase this is a generated file
 
 #include <KCalendarCore/Event>
@@ -268,7 +266,8 @@ public:
         mHolidayCheckCombo->setWhatsThis(KOPrefs::instance()->holidaysItem()->whatsThis());
 
         const QStringList regions = KHolidays::HolidayRegion::regionCodes();
-        QMap<QString, QString> regionsMap;
+        std::vector<std::pair<QString, QString>> regionsMap;
+        regionsMap.reserve(regions.size());
 
         for (const QString &regionCode : regions) {
             const QString name = KHolidays::HolidayRegion::name(regionCode);
@@ -281,15 +280,14 @@ public:
                 label = i18nc("@item:inlistbox Holiday region, region language", "%1 (%2)",
                               name, languageName);
             }
-            regionsMap.insert(label, regionCode);
+            regionsMap.push_back(std::make_pair(label, regionCode));
         }
+        std::sort(regionsMap.begin(), regionsMap.end(), [](const auto &lhs, const auto &rhs) { return lhs.first < rhs.first; });
 
         mHolidayCheckCombo->clear();
         mHolidayCheckCombo->setDefaultText(i18nc("@item:inlistbox", "Select Holiday Regions"));
-        QMapIterator<QString, QString> i(regionsMap);
-        while (i.hasNext()) {
-            i.next();
-            mHolidayCheckCombo->addItem(i.key(), i.value());
+        for (const auto &entry : regionsMap) {
+            mHolidayCheckCombo->addItem(entry.first, entry.second);
         }
 
         //QString regionStr = KHolidays::HolidayRegion::defaultRegionCode();
@@ -836,7 +834,7 @@ KOPrefsDialogColorsAndFonts::KOPrefsDialogColorsAndFonts(QWidget *parent)
     unsetCategoryColor->label()->setWhatsThis(unsetCategoryColor->button()->whatsThis());
     unsetCategoryColor->label()->setToolTip(unsetCategoryColor->button()->toolTip());
 
-    mCategoryCombo = new KPIM::TagCombo(categoryGroup);
+    mCategoryCombo = new Akonadi::TagSelectionComboBox(categoryGroup);
     mCategoryCombo->setWhatsThis(
         i18nc("@info:whatsthis",
               "Select here the event category you want to modify. "
@@ -960,7 +958,7 @@ void KOPrefsDialogColorsAndFonts::usrReadConfig()
 
 void KOPrefsDialogColorsAndFonts::useSystemColorToggle(bool useSystemColor)
 {
-    for (KColorButton *colorButton : mButtonsDisable) {
+    for (KColorButton *colorButton : qAsConst(mButtonsDisable)) {
         if (useSystemColor) {
             colorButton->setEnabled(false);
         } else {
@@ -1621,4 +1619,5 @@ void KOPrefsUserFeedBack::save()
     UserFeedBackManager::self()->userFeedbackProvider()->setTelemetryMode(mUserFeedbackWidget->telemetryMode());
     UserFeedBackManager::self()->userFeedbackProvider()->setSurveyInterval(mUserFeedbackWidget->surveyInterval());
 }
+
 #endif
