@@ -104,14 +104,14 @@ public:
         : start(0)
         , end(0)
     {
-        connect(&model, SIGNAL(rowsInserted(QModelIndex,int,int)), this,
-                SLOT(onRowsInserted(QModelIndex,int,int)));
-        connect(&model, SIGNAL(rowsRemoved(QModelIndex,int,int)), this,
-                SLOT(onRowsRemoved(QModelIndex,int,int)));
-        connect(&model, SIGNAL(rowsMoved(QModelIndex,int,int,QModelIndex,int)), this,
-                SLOT(onRowsMoved(QModelIndex,int,int,QModelIndex,int)));
-        connect(&model, SIGNAL(dataChanged(QModelIndex,QModelIndex)), this,
-                SLOT(onDataChanged(QModelIndex,QModelIndex)));
+        connect(&model, &QAbstractItemModel::rowsInserted, this,
+                &ModelSignalSpy::onRowsInserted);
+        connect(&model, &QAbstractItemModel::rowsRemoved, this,
+                &ModelSignalSpy::onRowsRemoved);
+        connect(&model, &QAbstractItemModel::rowsMoved, this,
+                &ModelSignalSpy::onRowsMoved);
+        connect(&model, &QAbstractItemModel::dataChanged, this,
+                &ModelSignalSpy::onDataChanged);
         connect(&model, &QAbstractItemModel::layoutChanged, this, &ModelSignalSpy::onLayoutChanged);
         connect(&model, &QAbstractItemModel::modelReset, this, &ModelSignalSpy::onModelReset);
     }
